# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: condition/nest_condition_futures.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from trade import trade_enum_pb2 as trade_dot_trade__enum__pb2
from trade import trade_pb2 as trade_dot_trade__pb2
from condition import condition_futures_pb2 as condition_dot_condition__futures__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='condition/nest_condition_futures.proto',
    package='nest_condition.futures',
    syntax='proto3',
    serialized_options=_b('\242\002\003NCF'),
    serialized_pb=_b(
        '\n&condition/nest_condition_futures.proto\x12\x16nest_condition.futures\x1a\x16trade/trade_enum.proto\x1a\x11trade/trade.proto\x1a!condition/condition_futures.proto\"\xc2\x03\n\rConditionItem\x12\x15\n\rinstrument_id\x18\x01 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x02 \x01(\t\x12(\n\tdirection\x18\x03 \x01(\x0e\x32\x15.trade.tag.ActionType\x12\x18\n\x10\x63omb_offset_flag\x18\x04 \x01(\t\x12\x33\n\x10order_price_type\x18\x05 \x01(\x0e\x32\x19.trade.tag.OrderPriceType\x12\x13\n\x0blimit_price\x18\x06 \x01(\x01\x12\x1d\n\x15volume_total_original\x18\x07 \x01(\r\x12.\n\tinit_flag\x18\x08 \x01(\x0e\x32\x1b.condition.futures.InitFlag\x12\x1a\n\x12valid_period_count\x18\t \x01(\r\x12\x11\n\tcondition\x18\n \x01(\t\x12\x16\n\x0e\x63ondition_type\x18\x0b \x01(\r\x12\x16\n\x0e\x63ondition_info\x18\x0c \x01(\t\x12\x16\n\x0estop_loss_type\x18\r \x01(\r\x12\x17\n\x0f\x62\x61se_price_type\x18\x0e \x01(\r\x12\x18\n\x10price_difference\x18\x0f \x01(\x01\"\xb8\x01\n\x11NestConditionInfo\x12%\n\x06source\x18\x01 \x01(\x0e\x32\x15.trade.tag.SourceType\x12<\n\tnest_type\x18\x02 \x01(\x0e\x32).nest_condition.futures.NestConditionType\x12>\n\x0f\x63ondition_items\x18\x03 \x03(\x0b\x32%.nest_condition.futures.ConditionItem\"\x95\x01\n\x12\x43onditionOrderItem\x12\x37\n\x14\x63ondition_order_info\x18\x01 \x01(\x0b\x32\x19.condition.futures.Report\x12\x46\n\x13nest_condition_info\x18\x02 \x01(\x0b\x32).nest_condition.futures.NestConditionInfo\"\x9c\x02\n\tInsertReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x13\n\x0binvestor_id\x18\x02 \x01(\t\x12\x11\n\tbroker_id\x18\x03 \x01(\t\x12,\n\x0einterface_type\x18\x04 \x01(\x0e\x32\x14.trade.InterfaceType\x12%\n\x06source\x18\x05 \x01(\x0e\x32\x15.trade.tag.SourceType\x12<\n\tnest_type\x18\x06 \x01(\x0e\x32).nest_condition.futures.NestConditionType\x12>\n\x0f\x63ondition_items\x18\x07 \x03(\x0b\x32%.nest_condition.futures.ConditionItem\"\x1d\n\tInsertRsp\x12\x10\n\x08order_no\x18\x01 \x01(\t\"\xca\x02\n\tModifyReq\x12\x10\n\x08order_no\x18\x01 \x01(\t\x12\x1a\n\x12\x63ondition_order_no\x18\x02 \x01(\t\x12\x14\n\x0cinvestor_key\x18\x03 \x01(\x04\x12\x13\n\x0binvestor_id\x18\x04 \x01(\t\x12\x11\n\tbroker_id\x18\x05 \x01(\t\x12,\n\x0einterface_type\x18\x06 \x01(\x0e\x32\x14.trade.InterfaceType\x12%\n\x06source\x18\x07 \x01(\x0e\x32\x15.trade.tag.SourceType\x12<\n\tnest_type\x18\x08 \x01(\x0e\x32).nest_condition.futures.NestConditionType\x12>\n\x0f\x63ondition_items\x18\t \x03(\x0b\x32%.nest_condition.futures.ConditionItem\"9\n\tModifyRsp\x12\x10\n\x08order_no\x18\x01 \x01(\t\x12\x1a\n\x12\x63ondition_order_no\x18\x02 \x01(\t\"\xa6\x02\n\x08QueryReq\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x10\n\x08order_no\x18\x02 \x01(\t\x12\x12\n\nstart_date\x18\x03 \x01(\r\x12\x10\n\x08\x65nd_date\x18\x04 \x01(\r\x12\x16\n\x0e\x63ondition_type\x18\x05 \x01(\r\x12\x38\n\x10\x63ondition_status\x18\x06 \x01(\x0e\x32\x1e.trade.tag.ConditionStatusType\x12\x13\n\x0binvestor_id\x18\x07 \x01(\t\x12\x11\n\tbroker_id\x18\x08 \x01(\t\x12,\n\x0einterface_type\x18\t \x01(\x0e\x32\x14.trade.InterfaceType\x12\x12\n\nbegin_time\x18\n \x01(\t\x12\x10\n\x08\x65nd_time\x18\x0b \x01(\t\"G\n\x08QueryRsp\x12;\n\x07results\x18\x01 \x03(\x0b\x32*.nest_condition.futures.ConditionOrderItem\"\x93\x05\n\rConditionInfo\x12\x14\n\x0cinvestor_key\x18\x01 \x01(\x04\x12\x13\n\x0binvestor_id\x18\x02 \x01(\t\x12\x11\n\tbroker_id\x18\x03 \x01(\t\x12,\n\x0einterface_type\x18\x04 \x01(\x0e\x32\x14.trade.InterfaceType\x12%\n\x06source\x18\x05 \x01(\x0e\x32\x15.trade.tag.SourceType\x12<\n\tnest_type\x18\x06 \x01(\x0e\x32).nest_condition.futures.NestConditionType\x12\x15\n\rinstrument_id\x18\x07 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x08 \x01(\t\x12(\n\tdirection\x18\t \x01(\x0e\x32\x15.trade.tag.ActionType\x12\x18\n\x10\x63omb_offset_flag\x18\n \x01(\t\x12\x33\n\x10order_price_type\x18\x0b \x01(\x0e\x32\x19.trade.tag.OrderPriceType\x12\x13\n\x0blimit_price\x18\x0c \x01(\x01\x12\x1d\n\x15volume_total_original\x18\r \x01(\r\x12.\n\tinit_flag\x18\x0e \x01(\x0e\x32\x1b.condition.futures.InitFlag\x12\x1a\n\x12valid_period_count\x18\x0f \x01(\r\x12\x11\n\tcondition\x18\x10 \x01(\t\x12\x16\n\x0e\x63ondition_type\x18\x11 \x01(\r\x12\x16\n\x0e\x63ondition_info\x18\x12 \x01(\t\x12\x16\n\x0estop_loss_type\x18\x13 \x01(\r\x12\x17\n\x0f\x62\x61se_price_type\x18\x14 \x01(\r\x12\x18\n\x10price_difference\x18\x15 \x01(\x01\"\xc1\x03\n\x11NestConditionItem\x12\x10\n\x08order_no\x18\x01 \x01(\t\x12\x14\n\x0cinvestor_key\x18\x02 \x01(\x04\x12\x13\n\x0binvestor_id\x18\x03 \x01(\t\x12\x11\n\tbroker_id\x18\x04 \x01(\t\x12,\n\x0einterface_type\x18\x05 \x01(\x0e\x32\x14.trade.InterfaceType\x12%\n\x06source\x18\x06 \x01(\x0e\x32\x15.trade.tag.SourceType\x12<\n\tnest_type\x18\x07 \x01(\x0e\x32).nest_condition.futures.NestConditionType\x12\x16\n\x0e\x63ondition_size\x18\x08 \x01(\r\x12\x13\n\x0binsert_time\x18\t \x01(\t\x12;\n\x06status\x18\n \x01(\x0e\x32+.nest_condition.futures.NestConditionStatus\x12\x12\n\nstatus_msg\x18\x0b \x01(\x0c\x12\x13\n\x0bupdate_time\x18\x0c \x01(\t\x12\x19\n\x11\x66irst_trade_price\x18\r \x01(\x01\x12\x1b\n\x13\x65ntrust_rival_price\x18\x0e \x01(\x01*U\n\x11NestConditionType\x12\x1d\n\x19NestConditionType_Default\x10\x00\x12!\n\x1dNestConditionType_OpenAndStop\x10\x01*\xd3\x01\n\x13NestConditionStatus\x12\x1f\n\x1bNestConditionStatus_Default\x10\x00\x12(\n$NestConditionStatus_OpenOrderCreated\x10\x01\x12*\n&NestConditionStatus_OpenOrderEntrusted\x10\x02\x12(\n$NestConditionStatus_OpenOrderTrading\x10\x03\x12\x1b\n\x17NestConditionStatus_End\x10\x04\x42\x06\xa2\x02\x03NCFb\x06proto3')
    ,
    dependencies=[trade_dot_trade__enum__pb2.DESCRIPTOR, trade_dot_trade__pb2.DESCRIPTOR,
                  condition_dot_condition__futures__pb2.DESCRIPTOR, ])

_NESTCONDITIONTYPE = _descriptor.EnumDescriptor(
    name='NestConditionType',
    full_name='nest_condition.futures.NestConditionType',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name='NestConditionType_Default', index=0, number=0,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='NestConditionType_OpenAndStop', index=1, number=1,
            serialized_options=None,
            type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=3130,
    serialized_end=3215,
)
_sym_db.RegisterEnumDescriptor(_NESTCONDITIONTYPE)

NestConditionType = enum_type_wrapper.EnumTypeWrapper(_NESTCONDITIONTYPE)
_NESTCONDITIONSTATUS = _descriptor.EnumDescriptor(
    name='NestConditionStatus',
    full_name='nest_condition.futures.NestConditionStatus',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name='NestConditionStatus_Default', index=0, number=0,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='NestConditionStatus_OpenOrderCreated', index=1, number=1,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='NestConditionStatus_OpenOrderEntrusted', index=2, number=2,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='NestConditionStatus_OpenOrderTrading', index=3, number=3,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='NestConditionStatus_End', index=4, number=4,
            serialized_options=None,
            type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=3218,
    serialized_end=3429,
)
_sym_db.RegisterEnumDescriptor(_NESTCONDITIONSTATUS)

NestConditionStatus = enum_type_wrapper.EnumTypeWrapper(_NESTCONDITIONSTATUS)
NestConditionType_Default = 0
NestConditionType_OpenAndStop = 1
NestConditionStatus_Default = 0
NestConditionStatus_OpenOrderCreated = 1
NestConditionStatus_OpenOrderEntrusted = 2
NestConditionStatus_OpenOrderTrading = 3
NestConditionStatus_End = 4

_CONDITIONITEM = _descriptor.Descriptor(
    name='ConditionItem',
    full_name='nest_condition.futures.ConditionItem',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='instrument_id', full_name='nest_condition.futures.ConditionItem.instrument_id', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='exchange_id', full_name='nest_condition.futures.ConditionItem.exchange_id', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='direction', full_name='nest_condition.futures.ConditionItem.direction', index=2,
            number=3, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='comb_offset_flag', full_name='nest_condition.futures.ConditionItem.comb_offset_flag', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_price_type', full_name='nest_condition.futures.ConditionItem.order_price_type', index=4,
            number=5, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='limit_price', full_name='nest_condition.futures.ConditionItem.limit_price', index=5,
            number=6, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='volume_total_original', full_name='nest_condition.futures.ConditionItem.volume_total_original',
            index=6,
            number=7, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='init_flag', full_name='nest_condition.futures.ConditionItem.init_flag', index=7,
            number=8, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='valid_period_count', full_name='nest_condition.futures.ConditionItem.valid_period_count', index=8,
            number=9, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition', full_name='nest_condition.futures.ConditionItem.condition', index=9,
            number=10, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_type', full_name='nest_condition.futures.ConditionItem.condition_type', index=10,
            number=11, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_info', full_name='nest_condition.futures.ConditionItem.condition_info', index=11,
            number=12, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='stop_loss_type', full_name='nest_condition.futures.ConditionItem.stop_loss_type', index=12,
            number=13, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='base_price_type', full_name='nest_condition.futures.ConditionItem.base_price_type', index=13,
            number=14, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='price_difference', full_name='nest_condition.futures.ConditionItem.price_difference', index=14,
            number=15, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=145,
    serialized_end=595,
)

_NESTCONDITIONINFO = _descriptor.Descriptor(
    name='NestConditionInfo',
    full_name='nest_condition.futures.NestConditionInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='source', full_name='nest_condition.futures.NestConditionInfo.source', index=0,
            number=1, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='nest_type', full_name='nest_condition.futures.NestConditionInfo.nest_type', index=1,
            number=2, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_items', full_name='nest_condition.futures.NestConditionInfo.condition_items', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=598,
    serialized_end=782,
)

_CONDITIONORDERITEM = _descriptor.Descriptor(
    name='ConditionOrderItem',
    full_name='nest_condition.futures.ConditionOrderItem',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='condition_order_info', full_name='nest_condition.futures.ConditionOrderItem.condition_order_info',
            index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='nest_condition_info', full_name='nest_condition.futures.ConditionOrderItem.nest_condition_info',
            index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=785,
    serialized_end=934,
)

_INSERTREQ = _descriptor.Descriptor(
    name='InsertReq',
    full_name='nest_condition.futures.InsertReq',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='nest_condition.futures.InsertReq.investor_key', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='nest_condition.futures.InsertReq.investor_id', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='broker_id', full_name='nest_condition.futures.InsertReq.broker_id', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='interface_type', full_name='nest_condition.futures.InsertReq.interface_type', index=3,
            number=4, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='source', full_name='nest_condition.futures.InsertReq.source', index=4,
            number=5, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='nest_type', full_name='nest_condition.futures.InsertReq.nest_type', index=5,
            number=6, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_items', full_name='nest_condition.futures.InsertReq.condition_items', index=6,
            number=7, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=937,
    serialized_end=1221,
)

_INSERTRSP = _descriptor.Descriptor(
    name='InsertRsp',
    full_name='nest_condition.futures.InsertRsp',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='order_no', full_name='nest_condition.futures.InsertRsp.order_no', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1223,
    serialized_end=1252,
)

_MODIFYREQ = _descriptor.Descriptor(
    name='ModifyReq',
    full_name='nest_condition.futures.ModifyReq',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='order_no', full_name='nest_condition.futures.ModifyReq.order_no', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_order_no', full_name='nest_condition.futures.ModifyReq.condition_order_no', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='nest_condition.futures.ModifyReq.investor_key', index=2,
            number=3, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='nest_condition.futures.ModifyReq.investor_id', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='broker_id', full_name='nest_condition.futures.ModifyReq.broker_id', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='interface_type', full_name='nest_condition.futures.ModifyReq.interface_type', index=5,
            number=6, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='source', full_name='nest_condition.futures.ModifyReq.source', index=6,
            number=7, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='nest_type', full_name='nest_condition.futures.ModifyReq.nest_type', index=7,
            number=8, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_items', full_name='nest_condition.futures.ModifyReq.condition_items', index=8,
            number=9, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1255,
    serialized_end=1585,
)

_MODIFYRSP = _descriptor.Descriptor(
    name='ModifyRsp',
    full_name='nest_condition.futures.ModifyRsp',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='order_no', full_name='nest_condition.futures.ModifyRsp.order_no', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_order_no', full_name='nest_condition.futures.ModifyRsp.condition_order_no', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1587,
    serialized_end=1644,
)

_QUERYREQ = _descriptor.Descriptor(
    name='QueryReq',
    full_name='nest_condition.futures.QueryReq',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='nest_condition.futures.QueryReq.investor_key', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_no', full_name='nest_condition.futures.QueryReq.order_no', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='start_date', full_name='nest_condition.futures.QueryReq.start_date', index=2,
            number=3, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='end_date', full_name='nest_condition.futures.QueryReq.end_date', index=3,
            number=4, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_type', full_name='nest_condition.futures.QueryReq.condition_type', index=4,
            number=5, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_status', full_name='nest_condition.futures.QueryReq.condition_status', index=5,
            number=6, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='nest_condition.futures.QueryReq.investor_id', index=6,
            number=7, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='broker_id', full_name='nest_condition.futures.QueryReq.broker_id', index=7,
            number=8, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='interface_type', full_name='nest_condition.futures.QueryReq.interface_type', index=8,
            number=9, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='begin_time', full_name='nest_condition.futures.QueryReq.begin_time', index=9,
            number=10, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='end_time', full_name='nest_condition.futures.QueryReq.end_time', index=10,
            number=11, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1647,
    serialized_end=1941,
)

_QUERYRSP = _descriptor.Descriptor(
    name='QueryRsp',
    full_name='nest_condition.futures.QueryRsp',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='results', full_name='nest_condition.futures.QueryRsp.results', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1943,
    serialized_end=2014,
)

_CONDITIONINFO = _descriptor.Descriptor(
    name='ConditionInfo',
    full_name='nest_condition.futures.ConditionInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='nest_condition.futures.ConditionInfo.investor_key', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='nest_condition.futures.ConditionInfo.investor_id', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='broker_id', full_name='nest_condition.futures.ConditionInfo.broker_id', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='interface_type', full_name='nest_condition.futures.ConditionInfo.interface_type', index=3,
            number=4, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='source', full_name='nest_condition.futures.ConditionInfo.source', index=4,
            number=5, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='nest_type', full_name='nest_condition.futures.ConditionInfo.nest_type', index=5,
            number=6, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='instrument_id', full_name='nest_condition.futures.ConditionInfo.instrument_id', index=6,
            number=7, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='exchange_id', full_name='nest_condition.futures.ConditionInfo.exchange_id', index=7,
            number=8, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='direction', full_name='nest_condition.futures.ConditionInfo.direction', index=8,
            number=9, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='comb_offset_flag', full_name='nest_condition.futures.ConditionInfo.comb_offset_flag', index=9,
            number=10, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='order_price_type', full_name='nest_condition.futures.ConditionInfo.order_price_type', index=10,
            number=11, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='limit_price', full_name='nest_condition.futures.ConditionInfo.limit_price', index=11,
            number=12, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='volume_total_original', full_name='nest_condition.futures.ConditionInfo.volume_total_original',
            index=12,
            number=13, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='init_flag', full_name='nest_condition.futures.ConditionInfo.init_flag', index=13,
            number=14, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='valid_period_count', full_name='nest_condition.futures.ConditionInfo.valid_period_count', index=14,
            number=15, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition', full_name='nest_condition.futures.ConditionInfo.condition', index=15,
            number=16, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_type', full_name='nest_condition.futures.ConditionInfo.condition_type', index=16,
            number=17, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_info', full_name='nest_condition.futures.ConditionInfo.condition_info', index=17,
            number=18, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='stop_loss_type', full_name='nest_condition.futures.ConditionInfo.stop_loss_type', index=18,
            number=19, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='base_price_type', full_name='nest_condition.futures.ConditionInfo.base_price_type', index=19,
            number=20, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='price_difference', full_name='nest_condition.futures.ConditionInfo.price_difference', index=20,
            number=21, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2017,
    serialized_end=2676,
)

_NESTCONDITIONITEM = _descriptor.Descriptor(
    name='NestConditionItem',
    full_name='nest_condition.futures.NestConditionItem',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='order_no', full_name='nest_condition.futures.NestConditionItem.order_no', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_key', full_name='nest_condition.futures.NestConditionItem.investor_key', index=1,
            number=2, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='investor_id', full_name='nest_condition.futures.NestConditionItem.investor_id', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='broker_id', full_name='nest_condition.futures.NestConditionItem.broker_id', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='interface_type', full_name='nest_condition.futures.NestConditionItem.interface_type', index=4,
            number=5, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='source', full_name='nest_condition.futures.NestConditionItem.source', index=5,
            number=6, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='nest_type', full_name='nest_condition.futures.NestConditionItem.nest_type', index=6,
            number=7, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='condition_size', full_name='nest_condition.futures.NestConditionItem.condition_size', index=7,
            number=8, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='insert_time', full_name='nest_condition.futures.NestConditionItem.insert_time', index=8,
            number=9, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='status', full_name='nest_condition.futures.NestConditionItem.status', index=9,
            number=10, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='status_msg', full_name='nest_condition.futures.NestConditionItem.status_msg', index=10,
            number=11, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='update_time', full_name='nest_condition.futures.NestConditionItem.update_time', index=11,
            number=12, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='first_trade_price', full_name='nest_condition.futures.NestConditionItem.first_trade_price', index=12,
            number=13, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='entrust_rival_price', full_name='nest_condition.futures.NestConditionItem.entrust_rival_price',
            index=13,
            number=14, type=1, cpp_type=5, label=1,
            has_default_value=False, default_value=float(0),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2679,
    serialized_end=3128,
)

_CONDITIONITEM.fields_by_name['direction'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_CONDITIONITEM.fields_by_name['order_price_type'].enum_type = trade_dot_trade__enum__pb2._ORDERPRICETYPE
_CONDITIONITEM.fields_by_name['init_flag'].enum_type = condition_dot_condition__futures__pb2._INITFLAG
_NESTCONDITIONINFO.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_NESTCONDITIONINFO.fields_by_name['nest_type'].enum_type = _NESTCONDITIONTYPE
_NESTCONDITIONINFO.fields_by_name['condition_items'].message_type = _CONDITIONITEM
_CONDITIONORDERITEM.fields_by_name['condition_order_info'].message_type = condition_dot_condition__futures__pb2._REPORT
_CONDITIONORDERITEM.fields_by_name['nest_condition_info'].message_type = _NESTCONDITIONINFO
_INSERTREQ.fields_by_name['interface_type'].enum_type = trade_dot_trade__pb2._INTERFACETYPE
_INSERTREQ.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_INSERTREQ.fields_by_name['nest_type'].enum_type = _NESTCONDITIONTYPE
_INSERTREQ.fields_by_name['condition_items'].message_type = _CONDITIONITEM
_MODIFYREQ.fields_by_name['interface_type'].enum_type = trade_dot_trade__pb2._INTERFACETYPE
_MODIFYREQ.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_MODIFYREQ.fields_by_name['nest_type'].enum_type = _NESTCONDITIONTYPE
_MODIFYREQ.fields_by_name['condition_items'].message_type = _CONDITIONITEM
_QUERYREQ.fields_by_name['condition_status'].enum_type = trade_dot_trade__enum__pb2._CONDITIONSTATUSTYPE
_QUERYREQ.fields_by_name['interface_type'].enum_type = trade_dot_trade__pb2._INTERFACETYPE
_QUERYRSP.fields_by_name['results'].message_type = _CONDITIONORDERITEM
_CONDITIONINFO.fields_by_name['interface_type'].enum_type = trade_dot_trade__pb2._INTERFACETYPE
_CONDITIONINFO.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_CONDITIONINFO.fields_by_name['nest_type'].enum_type = _NESTCONDITIONTYPE
_CONDITIONINFO.fields_by_name['direction'].enum_type = trade_dot_trade__enum__pb2._ACTIONTYPE
_CONDITIONINFO.fields_by_name['order_price_type'].enum_type = trade_dot_trade__enum__pb2._ORDERPRICETYPE
_CONDITIONINFO.fields_by_name['init_flag'].enum_type = condition_dot_condition__futures__pb2._INITFLAG
_NESTCONDITIONITEM.fields_by_name['interface_type'].enum_type = trade_dot_trade__pb2._INTERFACETYPE
_NESTCONDITIONITEM.fields_by_name['source'].enum_type = trade_dot_trade__enum__pb2._SOURCETYPE
_NESTCONDITIONITEM.fields_by_name['nest_type'].enum_type = _NESTCONDITIONTYPE
_NESTCONDITIONITEM.fields_by_name['status'].enum_type = _NESTCONDITIONSTATUS
DESCRIPTOR.message_types_by_name['ConditionItem'] = _CONDITIONITEM
DESCRIPTOR.message_types_by_name['NestConditionInfo'] = _NESTCONDITIONINFO
DESCRIPTOR.message_types_by_name['ConditionOrderItem'] = _CONDITIONORDERITEM
DESCRIPTOR.message_types_by_name['InsertReq'] = _INSERTREQ
DESCRIPTOR.message_types_by_name['InsertRsp'] = _INSERTRSP
DESCRIPTOR.message_types_by_name['ModifyReq'] = _MODIFYREQ
DESCRIPTOR.message_types_by_name['ModifyRsp'] = _MODIFYRSP
DESCRIPTOR.message_types_by_name['QueryReq'] = _QUERYREQ
DESCRIPTOR.message_types_by_name['QueryRsp'] = _QUERYRSP
DESCRIPTOR.message_types_by_name['ConditionInfo'] = _CONDITIONINFO
DESCRIPTOR.message_types_by_name['NestConditionItem'] = _NESTCONDITIONITEM
DESCRIPTOR.enum_types_by_name['NestConditionType'] = _NESTCONDITIONTYPE
DESCRIPTOR.enum_types_by_name['NestConditionStatus'] = _NESTCONDITIONSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConditionItem = _reflection.GeneratedProtocolMessageType('ConditionItem', (_message.Message,), {
    'DESCRIPTOR': _CONDITIONITEM,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.ConditionItem)
})
_sym_db.RegisterMessage(ConditionItem)

NestConditionInfo = _reflection.GeneratedProtocolMessageType('NestConditionInfo', (_message.Message,), {
    'DESCRIPTOR': _NESTCONDITIONINFO,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.NestConditionInfo)
})
_sym_db.RegisterMessage(NestConditionInfo)

ConditionOrderItem = _reflection.GeneratedProtocolMessageType('ConditionOrderItem', (_message.Message,), {
    'DESCRIPTOR': _CONDITIONORDERITEM,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.ConditionOrderItem)
})
_sym_db.RegisterMessage(ConditionOrderItem)

InsertReq = _reflection.GeneratedProtocolMessageType('InsertReq', (_message.Message,), {
    'DESCRIPTOR': _INSERTREQ,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.InsertReq)
})
_sym_db.RegisterMessage(InsertReq)

InsertRsp = _reflection.GeneratedProtocolMessageType('InsertRsp', (_message.Message,), {
    'DESCRIPTOR': _INSERTRSP,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.InsertRsp)
})
_sym_db.RegisterMessage(InsertRsp)

ModifyReq = _reflection.GeneratedProtocolMessageType('ModifyReq', (_message.Message,), {
    'DESCRIPTOR': _MODIFYREQ,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.ModifyReq)
})
_sym_db.RegisterMessage(ModifyReq)

ModifyRsp = _reflection.GeneratedProtocolMessageType('ModifyRsp', (_message.Message,), {
    'DESCRIPTOR': _MODIFYRSP,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.ModifyRsp)
})
_sym_db.RegisterMessage(ModifyRsp)

QueryReq = _reflection.GeneratedProtocolMessageType('QueryReq', (_message.Message,), {
    'DESCRIPTOR': _QUERYREQ,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.QueryReq)
})
_sym_db.RegisterMessage(QueryReq)

QueryRsp = _reflection.GeneratedProtocolMessageType('QueryRsp', (_message.Message,), {
    'DESCRIPTOR': _QUERYRSP,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.QueryRsp)
})
_sym_db.RegisterMessage(QueryRsp)

ConditionInfo = _reflection.GeneratedProtocolMessageType('ConditionInfo', (_message.Message,), {
    'DESCRIPTOR': _CONDITIONINFO,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.ConditionInfo)
})
_sym_db.RegisterMessage(ConditionInfo)

NestConditionItem = _reflection.GeneratedProtocolMessageType('NestConditionItem', (_message.Message,), {
    'DESCRIPTOR': _NESTCONDITIONITEM,
    '__module__': 'condition.nest_condition_futures_pb2'
    # @@protoc_insertion_point(class_scope:nest_condition.futures.NestConditionItem)
})
_sym_db.RegisterMessage(NestConditionItem)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
