# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='common.proto',
    package='common',
    syntax='proto3',
    serialized_options=_b('\242\002\003COM'),
    serialized_pb=_b(
        '\n\x0c\x63ommon.proto\x12\x06\x63ommon\"&\n\x05\x45rror\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\x0c\")\n\x03Log\x12\x11\n\tlog_level\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\x0c\x42\x06\xa2\x02\x03\x43OMb\x06proto3')
)

_ERROR = _descriptor.Descriptor(
    name='Error',
    full_name='common.Error',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='common.Error.code', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='message', full_name='common.Error.message', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=24,
    serialized_end=62,
)

_LOG = _descriptor.Descriptor(
    name='Log',
    full_name='common.Log',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='log_level', full_name='common.Log.log_level', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='message', full_name='common.Log.message', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=64,
    serialized_end=105,
)

DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['Log'] = _LOG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
    'DESCRIPTOR': _ERROR,
    '__module__': 'common_pb2'
    # @@protoc_insertion_point(class_scope:common.Error)
})
_sym_db.RegisterMessage(Error)

Log = _reflection.GeneratedProtocolMessageType('Log', (_message.Message,), {
    'DESCRIPTOR': _LOG,
    '__module__': 'common_pb2'
    # @@protoc_insertion_point(class_scope:common.Log)
})
_sym_db.RegisterMessage(Log)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
